@@ -88,21 +88,18 @@ class JoinTransformer:
                 else chunk.quote_type
             )
         except FlyntException as e:
-            if state.verbose:
-                print(f"Exception {e} during conversion of code '{str(chunk)}'")
-                traceback.print_exc()
+            quote_type = qt.double
 
-        else:
-            converted, changed = self.transform_func(str(chunk), quote_type=quote_type)
-            if changed:
-                contract_lines = chunk.n_lines - 1
-                if contract_lines == 0:
-                    line = self.src_lines[chunk.start_line]
-                    rest = line[chunk.end_idx :]
-                else:
-                    next_line = self.src_lines[chunk.start_line + contract_lines]
-                    rest = next_line[chunk.end_idx :]
-                self.maybe_replace(chunk, contract_lines, converted, rest)
+        converted, changed = self.transform_func(str(chunk), quote_type=quote_type)
+        if changed:
+            contract_lines = chunk.n_lines - 1
+            if contract_lines == 0:
+                line = self.src_lines[chunk.start_line]
+                rest = line[chunk.end_idx :]
+            else:
+                next_line = self.src_lines[chunk.start_line + contract_lines]
+                rest = next_line[chunk.end_idx :]
+            self.maybe_replace(chunk, contract_lines, converted, rest)
 
     def maybe_replace(self, chunk, contract_lines, converted, rest):
         if contract_lines:
